Module goto

Module goto 

Utilities for moving the cursor.

Functions

bot
Move the cursor to the bottom left of the screen.
down
Move the cursor down.
home
Move the cursor to the top left of screen.
left
Move the cursor left.
pos
Set cursor to a specific position.
right
Move the cursor right.
start
Move the cursor to the start of the line.
up
Move the cursor up.