pub fn enable_raw_mode()Expand description
Enable raw mode for the terminal.
Disable with disable_raw_mode.
Panics
If this fails to enable raw mode, panics with the message “failed to enable raw mode”.
pub fn enable_raw_mode()Enable raw mode for the terminal.
Disable with disable_raw_mode.
If this fails to enable raw mode, panics with the message “failed to enable raw mode”.