pub fn set_cursor_style(style: CursorStyle)Expand description
Changes the cursor style.
Panics
If this fails to set the cursor style, panics with the message “failed to change cursor style”.
pub fn set_cursor_style(style: CursorStyle)Changes the cursor style.
If this fails to set the cursor style, panics with the message “failed to change cursor style”.